@@ -17,12 +17,12 @@ impl Authenticate {
 
 #[derive(Debug)]
 pub struct AuthSuccess {
-    pub success_message: String,
+    pub success_message: Option<Vec<u8>>,
 }
 
 impl AuthSuccess {
     pub fn deserialize(buf: &mut &[u8]) -> Result<Self, ParseError> {
-        let success_message = types::read_string(buf)?.to_string();
+        let success_message = types::read_bytes_opt(buf)?.map(|b| b.to_owned());
 
         Ok(AuthSuccess { success_message })
     }
@@ -30,12 +30,12 @@ impl AuthSuccess {
 
 #[derive(Debug)]
 pub struct AuthChallenge {
-    pub authenticate_message: String,
+    pub authenticate_message: Option<Vec<u8>>,
 }
 
 impl AuthChallenge {
     pub fn deserialize(buf: &mut &[u8]) -> Result<Self, ParseError> {
-        let authenticate_message = types::read_string(buf)?.to_string();
+        let authenticate_message = types::read_bytes_opt(buf)?.map(|b| b.to_owned());
 
         Ok(AuthChallenge {
             authenticate_message,
